@@ -10,4 +10,4 @@
 pub use crate::isbar::subsets::IteratorProgress as __stati_IteratorProgress;
 pub use crate::iterator::ProgressTrackingAdaptor as __stati_ProgressTrackingAdaptor;
 pub use crate::IsBar as __stati_IsBar;
-pub use crate::IsBarWrapper as __stati_IsBarWrapper;
+pub use crate::wrapper::IsBarWrapper as __stati_IsBarWrapper;
